# Traktor

Traktor is a personal time tracking app inspired by
[Clockify](https://clockify.me/). Not all features are implemented. Missing
workspaces and billable flags - I personally don't use them, but if you plan
to use the app and you're missing those features, please send me an email and
I'll add them. 

At the moment it's command line only, but my intention is to make a web and
desktop app too.

The main reason for creating the app is that Clockify data is available only
for the last year (through the api) and I was exiting the window of one year.

I also wanted to have my personal data in my possession in an easily accessible
and backup-able format (sqlite3 database.)
